# Python: Asynchronous ZXArt.ee API Client

![PyPI - Python Version](https://img.shields.io/pypi/pyversions/zxart)
![PyPI - Version](https://img.shields.io/pypi/v/zxart)
![PyPI - Status](https://img.shields.io/pypi/status/zxart)
![PyPI - License](https://img.shields.io/pypi/l/zxart)
![PyPI - Downloads](https://img.shields.io/pypi/dm/zxart)

## About

Simple asynchronous Python [ZXArt.ee](https://zxart.ee/) API client.

## Installation

```bash
pip install zxart
```
